@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010-2012 Infrae. All rights reserved.
+# Copyright (c) 2010-2013 Infrae. All rights reserved.
 # See also LICENSE.txt
 
 import threading
@@ -63,8 +63,11 @@ def mount_all_databases():
                 # Get the database.
                 # If it doesn't exist yet, it will be created.
                 config.dbtab.getDatabase(name=name)
-                root.unrestrictedTraverse(path)
-                logger.info("Mounted %s on %s" % (name, path))
+                try:
+                    root.unrestrictedTraverse(path)
+                    logger.info("Mounted %s on %s" % (name, path))
+                except KeyError:
+                    logger.info("Skipping mount %s on %s (traversal failed; possibly not set up yet." % (name, path))
             except AttributeError:
                 pass
     connection.close()
@@ -107,7 +110,9 @@ def parse_raven_config(options):
     config = configuration_dict(options, 'raven', sep=".")
     for key in ['exclude_paths', 'include_paths', 'processors']:
         if key in config:
-            config[key] = configuration_list(config[key])
+            value = configuration_list(config[key])
+            if value:
+                config[key] = value
     if config:
         from .ravenplugin import RavenLoggingPlugin
         reporter.subscribe_to_errors(RavenLoggingPlugin(config))
@@ -142,7 +147,7 @@ def zope2_application_factory(global_conf, zope_conf, **options):
         debug_exceptions,
         zope_workers)
 
-# Utilities to read configuration options
+# Utilities to read configuration options from paster file
 
 def configuration_dict(options, key, sep="."):
     key_sep = key + sep
@@ -150,7 +155,9 @@ def configuration_dict(options, key, sep="."):
     for key, value in options.iteritems():
         if key.startswith(key_sep):
             prefix, result_key = key.split(sep, 1)
-            result[result_key] = value
+            value = value.strip()
+            if value:
+                result[result_key] = value
     return result
 
 def configuration_list(options, key, default=''):
